==> pcp_5.2.6.orig.tar.gz: pcp-5.2.6/README.md <==
![PCP](images/pcpicon.png)

[![CI](https://github.com/performancecopilot/pcp/workflows/CI/badge.svg)](https://performancecopilot.github.io/qa-reports/)
[![Coverity Scan Build Status](https://scan.coverity.com/projects/15853/badge.svg)](https://scan.coverity.com/projects/15853)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/1872/badge)](https://bestpractices.coreinfrastructure.org/projects/1872)
[![Mailing List](https://img.shields.io/badge/Mailing%20List-pcp-blue.svg)](https://groups.io/g/pcp)
[![Slack Team](https://img.shields.io/badge/Slack-pcp-blue.svg)](https://h7zo83mvt1.execute-api.us-west-2.amazonaws.com/Express/)
[![IRC #pcp](https://img.shields.io/badge/IRC-pcp-blue.svg)](https://webchat.freenode.net/#pcp)
[![Github Release](https://img.shields.io/github/release/performancecopilot/pcp.svg)](https://github.com/performancecopilot/pcp/releases/latest)

Performance Co-Pilot (PCP) provides a framework and services to support
system-level performance monitoring and management. It presents a unifying
abstraction for all of the performance data in a system, and many tools
for interrogating, retrieving and processing that data.

PCP is a feature-rich, mature, extensible, cross-platform toolkit
supporting both live and retrospective analysis. The distributed PCP
architecture makes it especially useful for those seeking centralized
monitoring of distributed processing.

See the [INSTALL](INSTALL.md) file for build, installation and configuration steps.
For more information and details on how to contribute to the PCP project
visit [pcp.io](https://pcp.io/community.html)

==> pcp_5.3.6.orig.tar.gz: pcp-5.3.6/README.md <==
![PCP](images/pcpicon.png)

[![CI](https://github.com/performancecopilot/pcp/workflows/CI/badge.svg)](https://performancecopilot.github.io/qa-reports/reports/latest/)
[![Coverity Scan Build Status](https://scan.coverity.com/projects/15853/badge.svg)](https://scan.coverity.com/projects/15853)
[![Documentation Status](https://readthedocs.org/projects/pcp/badge/?version=latest)](https://pcp.readthedocs.io)
[![Container](https://quay.io/repository/performancecopilot/pcp/status)](https://quay.io/repository/performancecopilot/pcp)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/1872/badge)](https://bestpractices.coreinfrastructure.org/projects/1872)
[![Mailing List](https://img.shields.io/badge/Mailing%20List-pcp-blue.svg)](https://groups.io/g/pcp)
[![Slack Team](https://img.shields.io/badge/Slack-pcp-blue.svg)](https://h7zo83mvt1.execute-api.us-west-2.amazonaws.com/Express/)
[![IRC #pcp](https://img.shields.io/badge/IRC-pcp-blue.svg)](https://web.libera.chat/#pcp)
[![Github Release](https://img.shields.io/github/release/performancecopilot/pcp.svg)](https://github.com/performancecopilot/pcp/releases/latest)

Performance Co-Pilot (PCP) provides a framework and services to support
system-level performance monitoring and management. It presents a unifying
abstraction for all of the performance data in a system, and many tools
for interrogating, retrieving and processing that data.

PCP is a feature-rich, mature, extensible, cross-platform toolkit
supporting both live and retrospective analysis. The distributed PCP
architecture makes it especially useful for those seeking centralized
monitoring of distributed processing.

See the [INSTALL](INSTALL.md) file for build, installation and configuration steps.
For more information and details on how to contribute to the PCP project
visit [pcp.io](https://pcp.io/community.html)
